#
# spec file for package ipw-firmware
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!_firmwaredir:%define _firmwaredir /lib/firmware}

Name:           ipw-firmware
Summary:        Firmware for Intel PRO/Wireless WLAN Cards
License:        SUSE-Firmware
Group:          Hardware/Wifi
Version:        9
Release:        23.10
%define version_2100 1.3
%define version_2200 2.4
%define version_3945 1.14.2
URL:            http://ipw2200.sourceforge.net/firmware.php
Source0:        ipw2100-fw-%{version_2100}.tar.bz2
Source1:        ipw2200-fw-%{version_2200}.tar.bz2
Source2:        ipw2200-fw-2.3.tar.bz2
Source3:        ipw2200-fw-2.2.tar.bz2
Source4:        ipw2200-fw-3.1.tar.bz2
BuildArch:      noarch
Requires(post): modutils grep
# Modules: ipw2100.ko ipw2200.ko
Supplements:    modalias(pci:v00008086d00001043sv0000103Csd00002741bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000252[0123456789BCD]bc*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000255[01345]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000256[0123567]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd000025[78]0bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000258[123567]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000259[012368]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd000025A0bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000270[12]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000271[12]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000272[12]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000273[12]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000274[12]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000275[1234]bc*sc*i*)
Supplements:    modalias(pci:v00008086d00001043sv00008086sd0000276[12]bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000104Fsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000422[0134]sv*sd*bc*sc*i*)
# Generated with: extract-modaliases -i ipw* kernel-default.rpm

%description
This package contains firmware binaries needed for Intel PRO/Wireless
2100/2200BG (aka Centrino) WLAN cards. The package is covered by the
Intel license. See http://ipw2100.sourceforge.net/firmware.php?fid=4.

%prep
%setup -cq -a1 -a2 -a3 -a4

%build

%install
mkdir -p %{buildroot}%{_firmwaredir}
cp *fw ipw2200-fw-3.1/*fw %{buildroot}%{_firmwaredir}
cp LICENSE %{buildroot}%{_firmwaredir}/LICENSE.ipw2x00

%post
test -f /.buildenv && exit 0
driver_active()
{
	for i in /sys/class/net/*/device/driver ; do
		test -e $i || continue
		DRV=$(basename `readlink $i`)
		test "$DRV" = "$1" && return 0
	done
	return 1
}
for M in ipw2100 ipw2200 ; do
	if /sbin/lsmod | grep -q ^$M ; then
		driver_active $M ||
		{ echo "Reloading module $M"; rmmod $M; modprobe $M; }
	fi
done

%files
%{_firmwaredir}/*

%changelog
* Sun Mar 21 2021 Michal Suchanek <msuchanek@suse.com>
- Fix build on Leap which does not have %%_firmwaredir
* Mon Oct 19 2020 Ludwig Nussel <lnussel@suse.de>
- use %%_firmwaredir
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Replace old specfile constructs.
* Sat Feb  2 2013 crrodriguez@opensuse.org
- PreReq modutils instead of module-init-tools otherwise
  we cannot switch to kmod cleanly
* Wed Dec 14 2011 coolo@suse.com
- as spdx.org has no concept of firmware, we decided to mark it as
  SUSE-Firmware
* Wed Dec  9 2009 seife@opensuse.org
- upgrade ipw2200 firmware to version 3.1
* Tue Mar 11 2008 hschaa@suse.de
- Remove ipw3945-firmware as ipw3945-kmp is not shipped anymore
  with 11.0 due to its successor iwl3945
* Fri Mar 16 2007 jg@suse.de
- removed /lib/firmware from filelist
* Fri Feb  2 2007 jg@suse.de
- reload modules after installation only when necessary
  (bug 210964)
- updated ipw3945 ucode to version 1.14.2, changes:
  * Fixed a fairly significant problem with some tuners not being
    able to lock properly onto a channel's frequency on B/G band.
  * Fixed a problem regarding power management.
  * Fxied lame scan results problem on Bugzilla #1085.
* Mon Aug  7 2006 seife@suse.de
- added ipw2000 firmware version 3.0 (for kernel 2.6.18)
* Mon Mar 20 2006 jg@suse.de
- fixed Supplements (bug 159079)
* Wed Mar  8 2006 cthiel@suse.de
- Prereq module-init-tools and grep, to make %%post scripts work
* Tue Mar  7 2006 agruen@suse.de
- Add modalias tags (155357).
* Mon Feb 27 2006 jg@suse.de
- added ipw3945 firmware
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 jg@suse.de
- added ipw2200 firmware version 2.4 (latest version)
- added ipw2200 firmware version 2.2 (needed for ipw2200 version
  that comes with kernel 2.6.14)
* Fri Aug 19 2005 ro@suse.de
- removed dropped hotplug package from nfb and requires
* Wed Jul 13 2005 jg@suse.de
- updated ipw2200 firmware to version 2.3
* Wed Jan 12 2005 jg@suse.de
- updated ipw2200 firmware to version 2.2
* Wed Dec 15 2004 jg@suse.de
- updated ipw2200 firmware to version 2.1
* Fri Oct  1 2004 jg@suse.de
- moved firmware binaries to /lib/firmware (bug 46583)
- reloading ipw modules after installation, so the modules get
  reinitialized with the firmware (bug 46556)
* Tue Sep 28 2004 jg@suse.de
- updated ipw2100 firmware to version 1.3 (needed for latest
  ipw2100 driver)
* Mon Sep  6 2004 jg@suse.de
- updated ipw2200 firmware to version 2.0
* Thu Sep  2 2004 jg@suse.de
- initial package
